"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContactSupport = exports.ContactSupportContent = void 0;
var react_1 = __importDefault(require("react"));
var react_auth_shared_1 = require("@brightlayer-ui/react-auth-shared");
var react_router_dom_1 = require("react-router-dom");
var Button_1 = __importDefault(require("@material-ui/core/Button"));
var CardActions_1 = __importDefault(require("@material-ui/core/CardActions"));
var CardContent_1 = __importDefault(require("@material-ui/core/CardContent"));
var CardHeader_1 = __importDefault(require("@material-ui/core/CardHeader"));
var Divider_1 = __importDefault(require("@material-ui/core/Divider"));
var Typography_1 = __importDefault(require("@material-ui/core/Typography"));
var createStyles_1 = __importDefault(require("@material-ui/core/styles/createStyles"));
var makeStyles_1 = __importDefault(require("@material-ui/core/styles/makeStyles"));
var useTheme_1 = __importDefault(require("@material-ui/core/styles/useTheme"));
var components_1 = require("../components");
var ChatBubbleOutline_1 = __importDefault(require("@material-ui/icons/ChatBubbleOutline"));
var styles_1 = require("../styles");
var clsx_1 = __importDefault(require("clsx"));
var useStyles = makeStyles_1.default(function (theme) {
    return createStyles_1.default({
        link: {
            fontWeight: 600,
            color: theme.palette.primary.main,
            textTransform: 'none',
            textDecoration: 'none',
            '&:visited': {
                color: theme.palette.primary.main,
            },
        },
    });
});
/**
 * Content for the Contact Us screen. This is exported separately
 * in the event that a user wishes to build another area in their
 * main application where users can view this information.
 *
 * @category Component
 */
var ContactSupportContent = function () {
    var t = react_auth_shared_1.useLanguageLocale().t;
    var theme = useTheme_1.default();
    var classes = useStyles();
    var _a = react_auth_shared_1.useInjectedUIContext(), contactPhone = _a.contactPhone, contactEmail = _a.contactEmail;
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement("div", { style: { fontSize: 70, marginBottom: theme.spacing(4), textAlign: 'center' } },
            react_1.default.createElement(ChatBubbleOutline_1.default, { fontSize: 'inherit', color: 'primary' })),
        react_1.default.createElement(Typography_1.default, { variant: 'body1', style: { marginBottom: theme.spacing(1) } }, t('blui:CONTACT_SUPPORT.GENERAL_QUESTIONS')),
        react_1.default.createElement(Typography_1.default, null,
            t('blui:CONTACT_SUPPORT.SUPPORT_MESSAGE'),
            react_1.default.createElement("a", { href: "mailto:" + contactEmail, className: classes.link }, contactEmail),
            "."),
        react_1.default.createElement(Typography_1.default, { variant: 'body1', style: { marginTop: theme.spacing(4), marginBottom: theme.spacing(1) } }, t('blui:CONTACT_SUPPORT.EMERGENCY_SUPPORT')),
        react_1.default.createElement(Typography_1.default, null,
            t('blui:CONTACT_SUPPORT.TECHNICAL_ASSISTANCE'),
            react_1.default.createElement("a", { href: "tel:" + contactPhone, className: classes.link }, contactPhone),
            ".")));
};
exports.ContactSupportContent = ContactSupportContent;
/**
 * Container that renders a screen with contact information for
 * support with the application. Contact information is pulled
 * from the context passed into the workflow.
 *
 * @category Component
 */
var ContactSupport = function () {
    var _a;
    var t = react_auth_shared_1.useLanguageLocale().t;
    var history = react_router_dom_1.useHistory();
    var classes = styles_1.useDialogStyles();
    return (react_1.default.createElement(components_1.BrandedCardContainer, null,
        react_1.default.createElement(CardHeader_1.default, { title: react_1.default.createElement(Typography_1.default, { variant: 'h6' }, t('blui:USER_MENU.CONTACT_US')), className: classes.dialogTitle }),
        react_1.default.createElement(CardContent_1.default, { className: classes.dialogContent },
            react_1.default.createElement(exports.ContactSupportContent, null)),
        react_1.default.createElement(Divider_1.default, null),
        react_1.default.createElement(CardActions_1.default, { className: classes.dialogActions },
            react_1.default.createElement(Button_1.default, { variant: "contained", color: "primary", disableElevation: true, className: clsx_1.default(classes.dialogButton, (_a = {}, _a[classes.fullWidth] = true, _a)), onClick: function () { return history.goBack(); } }, t('blui:ACTIONS.OKAY')))));
};
exports.ContactSupport = ContactSupport;
